==> formant-1.230.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_query_api_client/api/analytics/analytics_controller_list_device_streams.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ...client import AuthenticatedClient
from ...models.query_by_device_request import QueryByDeviceRequest
from ...models.stream_column_list_response import StreamColumnListResponse
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,
) -> Dict[str, Any]:
    url = "{}/analytics/streams/filter".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[StreamColumnListResponse]:
    if response.status_code == HTTPStatus.OK:
        response_200 = StreamColumnListResponse.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[StreamColumnListResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,
) -> Response[StreamColumnListResponse]:
    """List device streams

     Retrieves all distinct streams filtered by device
    Resource: analytics
    Authorized roles: viewer

    Args:
        json_body (QueryByDeviceRequest):

    Returns:
        Response[StreamColumnListResponse]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,
) -> Optional[StreamColumnListResponse]:
    """List device streams

     Retrieves all distinct streams filtered by device
    Resource: analytics
    Authorized roles: viewer

    Args:
        json_body (QueryByDeviceRequest):

    Returns:
        Response[StreamColumnListResponse]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,
) -> Response[StreamColumnListResponse]:
    """List device streams

     Retrieves all distinct streams filtered by device
    Resource: analytics
    Authorized roles: viewer

    Args:
        json_body (QueryByDeviceRequest):

    Returns:
        Response[StreamColumnListResponse]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,
) -> Optional[StreamColumnListResponse]:
    """List device streams

     Retrieves all distinct streams filtered by device
    Resource: analytics
    Authorized roles: viewer

    Args:
        json_body (QueryByDeviceRequest):

    Returns:
        Response[StreamColumnListResponse]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> formant-1.268.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_query_api_client/api/analytics/analytics_controller_list_device_streams.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ...client import AuthenticatedClient
from ...models.query_by_device_request import QueryByDeviceRequest
from ...models.stream_column_list_response import StreamColumnListResponse
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,

) -> Dict[str, Any]:
    url = "{}/analytics/streams/filter".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    json_json_body = json_body.to_dict()



    

    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[StreamColumnListResponse]:
    if response.status_code == HTTPStatus.OK:
        response_200 = StreamColumnListResponse.from_dict(response.json())



        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[StreamColumnListResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,

) -> Response[StreamColumnListResponse]:
    """List device streams

     Retrieves all distinct streams filtered by device
    Resource: analytics
    Authorized roles: viewer

    Args:
        json_body (QueryByDeviceRequest):

    Returns:
        Response[StreamColumnListResponse]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)

def sync(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,

) -> Optional[StreamColumnListResponse]:
    """List device streams

     Retrieves all distinct streams filtered by device
    Resource: analytics
    Authorized roles: viewer

    Args:
        json_body (QueryByDeviceRequest):

    Returns:
        Response[StreamColumnListResponse]
    """


    return sync_detailed(
        client=client,
json_body=json_body,

    ).parsed

async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,

) -> Response[StreamColumnListResponse]:
    """List device streams

     Retrieves all distinct streams filtered by device
    Resource: analytics
    Authorized roles: viewer

    Args:
        json_body (QueryByDeviceRequest):

    Returns:
        Response[StreamColumnListResponse]
    """


    kwargs = _get_kwargs(
        client=client,
json_body=json_body,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(response=response)

async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: QueryByDeviceRequest,

) -> Optional[StreamColumnListResponse]:
    """List device streams

     Retrieves all distinct streams filtered by device
    Resource: analytics
    Authorized roles: viewer

    Args:
        json_body (QueryByDeviceRequest):

    Returns:
        Response[StreamColumnListResponse]
    """


    return (await asyncio_detailed(
        client=client,
json_body=json_body,

    )).parsed
